@@ -28,13 +28,13 @@ class Publish:
             sh.poetry("run", "pytest")
         except sh.ErrorReturnCode_5:
             pass
-        sh.poetry("version", self.rule)
-        sh.poetry("build")
+        print(sh.poetry("version", self.rule))
+        print(sh.poetry("build"))
         sh.poetry("publish")
         sh.git("commit", "-a", "-m", "Bump version in pyproject.toml")
         sh.git("push")
         sh.gh("release", "create", sh.poetry("version", "-s"),
-              sh.tail("-n1", sh.grep(".whl", sh.ls("-tr", "dist"))))
+              sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"), "-n1"))
         sh.git("pull")
         return 0
 
